from setuptools import setup

setup(name='guessgame',
      version='0.1',
      description='Guess Game',
      packages=['guessgame'],
      zip_safe=False)
# https://packaging.python.org/tutorials/packaging-projects/